# Contributing Guidelines

Hello! Thanks for your interest in contributing to the codebase.

## How to contribute

TBD


## Submitting a pull request

To make an efficient review process, we very much appreciate if the PR commits

- follow the [conventional commits guidelines](https://www.conventionalcommits.org/),
- follow the [7 rules of commit messages](https://chris.beams.io/posts/git-commit/), and
- are rearranged to squash trivial commits together (use [git rebase](http://gitready.com/advanced/2009/03/20/reorder-commits-with-rebase.html)).
